.. _all-salt.states:

==================================
Full list of builtin state modules
==================================

.. currentmodule:: salt.states

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    alias
    alternatives
    apache
    apache_module
    aptpkg
    archive
    artifactory
    at
    augeas
    aws_sqs
    beacon
    bigip
    blockdev
    boto_asg
    boto_cfn
    boto_cloudwatch_alarm
    boto_dynamodb
    boto_ec2
    boto_elasticache
    boto_elb
    boto_iam
    boto_iam_role
    boto_kms
    boto_lc
    boto_rds
    boto_route53
    boto_secgroup
    boto_sns
    boto_sqs
    boto_vpc
    bower
    cabal
    chef
    cloud
    cmd
    composer
    cron
    cyg
    ddns
    debconfmod
    dellchassis
    disk
    dockerio
    dockerng
    drac
    elasticsearch_index
    elasticsearch_index_template
    environ
    eselect
    etcd_mod
    esxi
    event
    file
    firewalld
    gem
    git
    glance
    glusterfs
    gnomedesktop
    grafana
    grains
    group
    hg
    hipchat
    host
    htpasswd
    http
    ifttt
    incron
    influxdb_database
    influxdb_user
    ini_manage
    ipmi
    ipset
    iptables
    jboss7
    keyboard
    keystone
    kmod
    layman
    libvirt
    linux_acl
    locale
    lvm
    lvs_server
    lvs_service
    lxc
    makeconf
    mdadm
    memcached
    modjk
    modjk_worker
    module
    mongodb_database
    mongodb_user
    monit
    mount
    mysql_database
    mysql_grants
    mysql_query
    mysql_user
    network
    nftables
    npm
    ntp
    openstack_config
    pagerduty
    pagerduty_escalation_policy
    pagerduty_schedule
    pagerduty_service
    pagerduty_user
    pecl
    pip_state
    pkg
    pkgbuild
    pkgng
    pkgrepo
    portage_config
    ports
    postgres_database
    postgres_extension
    postgres_group
    postgres_schema
    postgres_tablespace
    postgres_user
    powerpath
    process
    pushover
    pyenv
    pyrax_queues
    quota
    rabbitmq_cluster
    rabbitmq_plugin
    rabbitmq_policy
    rabbitmq_user
    rabbitmq_vhost
    rbenv
    rdp
    redismod
    reg
    rvm
    saltmod
    schedule
    selinux
    serverdensity_device
    service
    slack
    smtp
    splunk_search
    ssh_auth
    ssh_known_hosts
    stateconf
    status
    stormpath_account
    supervisord
    svn
    sysctl
    syslog_ng
    sysrc
    test
    timezone
    tls
    tomcat
    trafficserver
    tuned
    uptime
    user
    vbox_guest
    victorops
    virtualenv_mod
    win_dacl
    win_dns_client
    win_firewall
    win_network
    win_path
    win_powercfg
    win_servermanager
    win_system
    win_update
    winrepo
    x509
    xmpp
    zcbuildout
    zk_concurrency
